@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """Infoset serialization format styles.
 
 This modules provides methods assisting the serialization module
@@ -10,8 +12,8 @@ see also http://web.chad.org/projects/smartypants.py/).
 
 """
 
-__revision__ = "$Rev: 421 $"
-__date__ = "$Date: 2006-10-22 07:02:46 -0400 (Sun, 22 Oct 2006) $"
+__revision__ = "$Rev: 492 $"
+__date__ = "$Date: 2007-07-06 21:38:45 -0400 (Fri, 06 Jul 2007) $"
 __author__ = "Christoph Zwerschke (cito@online.de)"
 __copyright__ = "Copyright 2006, Christoph Zwerschke"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -252,7 +254,7 @@ class Format(object):
         if stupefy:
             filters.append(self.stupefy)
         if educate_backticks and not educate_quotes:
-                filters.append(self.educate_backticks)
+            filters.append(self.educate_backticks)
         if educate_dashes:
             filters.append(self.educate_dashes)
         if educate_ellipses:
@@ -286,7 +288,7 @@ class Format(object):
             if value is not None:
                 try:
                     if value == getattr(Format, attr):
-                        value = None
+                        value = attr in ('wrap', 'indent') and True or None
                 except AttributeError:
                     pass
                 if value is not None:
@@ -294,16 +296,17 @@ class Format(object):
         for f in self.text_filters + self.context_filters:
             attr = f.__name__
             if attr == 'indent_lines':
-                if 'indent' not in parms:
+                if 'indent' not in args:
                     args['indent'] = True
             elif attr == 'wrap_lines':
-                if 'wrap' not in parms:
+                if 'wrap' not in args:
                     args['wrap'] = True
             else:
                 args[attr] = True
         if 'with_backticks' in args:
+            if args['with_backticks']:
+                args['educate_backticks'] = True
             del args['with_backticks']
-            args['educate_backticks'] = True
         if ('educate_quotes' in args
             and 'educate_backticks' in args
             and 'educate_dashes' in args
@@ -451,12 +454,6 @@ class Format(object):
 
     # Typographic formatting with context character
 
-    def educate_quotes_filter(self, s, last_char=None, next_char=None):
-        """Educate quotes filter (needs context characters)."""
-        return educate_quotes(s, last_char, next_char,
-            self.apostrophe, self.squotes, self.dquotes,
-            self.educate_backticks)
-
     def educate_quotes(self, s, last_char=None, next_char=None):
         """Use proper typographic quotes in the text.
 
@@ -544,6 +541,8 @@ class Format(object):
 output_formats = {
     'default':
         Format(no_empty_lines=True),
+    'straight':
+        Format(),
     'compact':
         Format(simple_whitespace=True),
     'newlines':
