@@ -1,3 +1,6 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 """Pythonic, XML Templating
 
 Kid is a simple, Python-based template language for generating and
@@ -8,10 +11,10 @@ complexity stamped out (well, eventually :).
 
 """
 
-__revision__ = "$Rev: 436 $"
-__date__ = "$Date: 2006-11-26 04:56:03 -0500 (Sun, 26 Nov 2006) $"
+__revision__ = "$Rev: 497 $"
+__date__ = "$Date: 2007-07-16 14:48:50 -0400 (Mon, 16 Jul 2007) $"
 
-version = "0.9.4"
+version = "0.9.6"
 author = "Ryan Tomayko"
 email = "rtomayko@gmail.com"
 copyright = "Copyright 2004-2006, Ryan Tomayko, " \
