@@ -1,42 +1,42 @@
+# -*- coding: utf-8 -*-
+
 """Infoset serialization formats (XML, XHTML, HTML, etc)"""
 
-__revision__ = "$Rev: 430 $"
-__date__ = "$Date: 2006-11-03 15:21:49 -0500 (Fri, 03 Nov 2006) $"
+__revision__ = "$Rev: 492 $"
+__date__ = "$Date: 2007-07-06 21:38:45 -0400 (Fri, 06 Jul 2007) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
-import re
-import string
+import htmlentitydefs
 
 try:
     set
 except NameError: # fallback for Python 2.3
     from sets import Set as set
 
-from kid.et import *
-from kid.parser import *
-from kid.parser import _coalesce
-from kid.format import *
-
-# bring in well known namespaces
+from kid.element import Element, Comment, ProcessingInstruction, \
+    Fragment, QName, namespaces, encode_entity, raise_serialization_error
 import kid.namespace as namespace
-xml_uri = namespace.xml.uri
-xhtml_uri = namespace.xhtml.uri
+from kid.parser import START, END, TEXT, COMMENT, PI, _coalesce
+from kid.format import Format, output_formats
 
 __all__ = ['doctypes', 'Serializer', 'XMLSerializer', 'HTMLSerializer']
 
+# bring in well known namespaces
+xml_uri = namespace.xml.uri
+xhtml_uri = namespace.xhtml.uri
 
 # This is the default entity map:
-import htmlentitydefs
 default_entity_map = {}
 for k, v in htmlentitydefs.codepoint2name.items():
     default_entity_map[unichr(k)] = "&%s;" % v
 
-
 # Some common doctypes.
 # You can pass doctype strings from here or doctype tuples to Serializers.
 doctypes = {
+    'wml': ('wml', "-//WAPFORUM//DTD WML 1.1//EN",
+        "http://www.wapforum.org/DTD/wml_1.1.xml"),
     'xhtml-strict': ('html', "-//W3C//DTD XHTML 1.0 Strict//EN",
         "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"),
     'xhtml': ('html', "-//W3C//DTD XHTML 1.0 Transitional//EN",
@@ -184,7 +184,7 @@ class Serializer(object):
                             if wrap is not None:
                                 text = wrap_lines(text, wrap, offset,
                                     indent_width(level*indent))
-                            if '\n' in text:
+                            if '\n' in text and indent_level:
                                 indent_level[-1] = True
                             if new_line:
                                 if lstrip_blanks(text)[:1] != '\n':
@@ -223,10 +223,7 @@ class Serializer(object):
                                         text = lstrip_lines(text)
                                     new_line = True
                             elif text:
-                                if level > 0:
-                                    text = indent_lines(text, level*indent)
-                                else:
-                                    text = lstrip_lines(text)
+                                text = indent_lines(text, level*indent)
                     if tag == Comment or self.is_formatted(tag):
                         if ev == START:
                             formatted += 1
@@ -408,7 +405,7 @@ class XMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return encode_entity(text, map=entity_map)
+                    return encode_entity(text, entities=entity_map)
             text = text.replace("&", "&amp;")
             text = text.replace("<", "&lt;")
         except (TypeError, AttributeError):
@@ -423,7 +420,7 @@ class XMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return encode_entity(text, map=entity_map)
+                    return encode_entity(text, entities=entity_map)
             text = text.replace("&", "&amp;")
             text = text.replace("<", "&lt;")
             text = text.replace("\"", "&quot;")
@@ -505,6 +502,7 @@ class HTMLBased(object):
                                 meta_item = Element(meta_tag, **attributes)
                                 yield START, meta_item
                                 yield END, meta_item
+                                yield TEXT, '\n'
                             done = True
                     elif tag == 'head' and ev == START:
                         meta_tag = item.tag[:-4] + 'meta'
@@ -514,7 +512,8 @@ class HTMLBased(object):
 class HTMLSerializer(HTMLBased, Serializer):
 
     doctype = doctypes['html']
-    transpose = None
+    transpose = False
+    inject_type = True
     entity_map = None
 
     noescape_elements = set([
@@ -525,7 +524,7 @@ class HTMLSerializer(HTMLBased, Serializer):
         'noresize', 'noshade', 'nowrap'])
 
     def __init__(self, encoding='utf-8', doctype=None, transpose=False,
-            inject_type=True, entity_map=None, format=None):
+            inject_type=None, entity_map=None, format=None):
         """Initialize HTMLSerializer.
 
         You can change the following parameters:
@@ -533,6 +532,7 @@ class HTMLSerializer(HTMLBased, Serializer):
         encoding: the output encoding
         doctype: add doctype (None, string, tuple)
         transpose: alter tag names (None, True/False, callable)
+        inject_type: inject content type (True/False)
         entity_map: use named entities for output (True/False or mapping)
         format: format to be applied (string or instance of Format)
 
@@ -540,8 +540,7 @@ class HTMLSerializer(HTMLBased, Serializer):
         Serializer.__init__(self, encoding=encoding, format=format)
         if doctype is not None:
             self.doctype = doctype
-        if transpose is not None:
-            self.transpose = transpose
+        self.transpose = transpose
         if inject_type is not None:
             self.inject_type = inject_type
         if entity_map is not None:
@@ -596,9 +595,9 @@ class HTMLSerializer(HTMLBased, Serializer):
         if transpose is not None:
             if not callable(transpose):
                 if transpose:
-                    transpose = string.upper
+                    transpose = lambda s: s.upper()
                 else:
-                    transpose = string.lower
+                    transpose = lambda s: s.lower()
 
         escape_cdata = HTMLSerializer.escape_cdata
         escape_attrib = HTMLSerializer.escape_attrib
@@ -634,18 +633,16 @@ class HTMLSerializer(HTMLBased, Serializer):
             elif ev == START:
                 if item.tag == Comment:
                     yield "<!--%s-->" % item.text.encode(encoding)
-                    lastev = COMMENT
                     continue
                 elif item.tag == ProcessingInstruction:
                     yield "<?%s>" % item.text.encode(encoding)
-                    lastev = PI
                     continue
                 elif item.tag == Fragment:
                     continue
                 else:
                     names.push(namespaces(item, remove=True))
                     tag = item.tag
-                    uri, localname, qname = grok_name(tag)
+                    qname = grok_name(tag)[2]
                     # push this name on the stack so we know where we are
                     current = qname.lower()
                     stack.append(current)
@@ -653,9 +650,10 @@ class HTMLSerializer(HTMLBased, Serializer):
                     attrs = item.attrib.items()
                     if attrs:
                         for k, v in attrs:
-                            u, l, q = grok_name(k)
+                            q = grok_name(k)[2]
                             lq = q.lower()
-                            if lq == 'xml:lang': continue
+                            if lq == 'xml:lang':
+                                continue
                             if self.is_boolean_attribute(lq):
                                 # XXX: what if v is 0, false, or no.
                                 #      should we omit the attribute?
@@ -670,7 +668,7 @@ class HTMLSerializer(HTMLBased, Serializer):
                 current = stack.pop()
                 if not self.can_be_empty_element(current):
                     tag = item.tag
-                    uri, localname, qname = grok_name(tag)
+                    qname = grok_name(tag)[2]
                     yield "</%s>" % qname.encode(encoding)
                 current = stack[-1]
                 names.pop()
@@ -682,7 +680,7 @@ class HTMLSerializer(HTMLBased, Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return encode_entity(text, map=entity_map)
+                    return encode_entity(text, entities=entity_map)
             if escape:
                 text = text.replace("&", "&amp;")
                 text = text.replace("<", "&lt;")
@@ -698,7 +696,7 @@ class HTMLSerializer(HTMLBased, Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return encode_entity(text, map=entity_map)
+                    return encode_entity(text, entities=entity_map)
             text = text.replace("&", "&amp;")
             text = text.replace("\"", "&quot;")
         except (TypeError, AttributeError):
@@ -710,9 +708,10 @@ class HTMLSerializer(HTMLBased, Serializer):
 class XHTMLSerializer(HTMLBased, XMLSerializer):
 
     doctype = doctypes['xhtml']
+    inject_type = True
 
     def __init__(self, encoding='utf-8', decl=None, doctype=None,
-            inject_type=True, entity_map=None, namespaces=None, format=None):
+            inject_type=None, entity_map=None, namespaces=None, format=None):
         """Initialize XHTMLSerializer."""
         XMLSerializer.__init__(self, encoding=encoding,
             decl=decl, doctype=doctype, entity_map=entity_map,
@@ -729,6 +728,7 @@ class XHTMLSerializer(HTMLBased, XMLSerializer):
 
     def generate(self, stream, encoding=None,
             fragment=False, format=None):
+        encoding = encoding or self.encoding or 'utf-8'
         inject_type = self.inject_type
         format = self._get_format(format)
         if format:
