@@ -1,31 +1,39 @@
+# -*- coding: utf-8 -*-
+
 """Utility functions used by generated kid modules."""
 
-__revision__ = "$Rev: 433 $"
-__date__ = "$Date: 2006-11-11 12:41:35 -0500 (Sat, 11 Nov 2006) $"
+__revision__ = "$Rev: 492 $"
+__date__ = "$Date: 2007-07-06 21:38:45 -0400 (Fri, 06 Jul 2007) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
 import inspect
 import sys
-from types import TypeType, ModuleType, ClassType
+from types import TypeType, ModuleType, ClassType, GeneratorType
 import itertools
 
 # these are for use by template code
 import kid
-from kid.parser import XML, document, ElementStream, \
-    START, END, TEXT, START_NS, COMMENT, PI, DOCTYPE, \
-    XML_DECL, to_unicode
-from kid.et import Element, SubElement, \
-    Comment, ProcessingInstruction
+from kid.parser import XML, document, ElementStream, START, END, TEXT, \
+    START_NS, COMMENT, PI, DOCTYPE, XML_DECL, to_unicode
+from kid.element import Element, SubElement, Comment, ProcessingInstruction
+
+__all__ = ['XML', 'document', 'ElementStream',
+    'Element', 'SubElement', 'Comment', 'ProcessingInstruction',
+    'START', 'END', 'TEXT', 'START_NS', 'COMMENT', 'PI',
+    'DOCTYPE', 'XML_DECL']
+
 
 class TemplateError(Exception): pass
 class TemplateNotFound(TemplateError): pass
+class TemplateImportError(TemplateError): pass
 class TemplateDictError(TemplateError): pass
 class TemplateAttrsError(TemplateError): pass
 class TemplateExtendsError(TemplateError): pass
 class TemplateLayoutError(TemplateError): pass
 
+
 _local_excludes = ['generate', 'module', 'parser', 'serialize', 'transform', 'write']
 def get_locals(inst, _locals=None):
     if _locals is None:
@@ -43,8 +51,7 @@ def get_base_class(thing, from_file=None, arg=None):
     if thing is None:
         return kid.BaseTemplate
     if isinstance(thing, TypeType):
-        if issubclass(thing, kid.BaseTemplate):
-            return thing
+        return thing
     elif isinstance(thing, ModuleType):
         try:
             cls = thing.Template
@@ -186,6 +193,8 @@ def generate_content(content):
         return [(TEXT, content)]
     elif isinstance(content, (ElementStream, kid.BaseTemplate)):
         return content
+    elif isinstance(content, GeneratorType):
+        return ElementStream(content)
     elif hasattr(content, 'tag') and hasattr(content, 'attrib'):
         # if we get an Element back, make it an ElementStream
         return ElementStream(content)
@@ -270,8 +279,3 @@ def update_attrs(attrib, attrs, globals, locals):
 def make_updated_attrib(attrib, attrs, globals, locals, encoding=None):
     """"Generate unicode strings in updated dictionary."""
     return make_attrib(update_attrs(attrib, attrs, globals, locals), encoding)
-
-__all__ = ['XML', 'document', 'ElementStream',
-           'Element', 'SubElement', 'Comment', 'ProcessingInstruction',
-           'START', 'END', 'TEXT', 'START_NS', 'COMMENT',
-           'PI', 'DOCTYPE', 'XML_DECL']
