@@ -1,7 +1,9 @@
-"""kid package tests."""
+# -*- coding: utf-8 -*-
 
-__revision__ = "$Rev: 455 $"
-__date__ = "$Date: 2006-12-21 01:42:34 -0500 (Thu, 21 Dec 2006) $"
+"""Kid package tests."""
+
+__revision__ = "$Rev: 492 $"
+__date__ = "$Date: 2007-07-06 21:38:45 -0400 (Fri, 06 Jul 2007) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
