@@ -1,11 +1,11 @@
 """Unit Tests for formatted output."""
 
-__revision__ = "$Rev: 429 $"
+__revision__ = "$Rev: 486 $"
 __author__ = "Christoph Zwerschke <cito@online.de>"
 __copyright__ = "Copyright 2006, Christoph Zwerschke"
 
 import kid
-from kid.format import *
+from kid.format import Format
 
 nbsp = u'\u00a0'
 string1 = ' \t \n \t Hello, World \n \t '
@@ -21,6 +21,13 @@ def serialize(source, format=None, output='html', encoding='utf-8'):
     return t.serialize(encoding=encoding, format=format, output=output,
         fragment=True) # so that output will not be stripped
 
+def test_format_repr():
+    from kid.format import output_formats
+    repr_dict = lambda d: dict([(k, repr(v)) for k, v in d.items()])
+    for format in output_formats.values():
+        d = [repr_dict(f.__dict__) for f in (format, eval(repr(format)))]
+        assert d[0] == d[1]
+
 def test_lstrip():
     lstrip = Format.lstrip
     for c in ' \t\r\n':
@@ -451,6 +458,15 @@ def test_format_indent():
         '<h1>Hello</h1>\n\t\t</div>\n\t</pre>\n</body>\n</html>')
     s = serialize(xml, format, 'plain')
     assert '\n\t\t\tHello\n' in s
+    xml = '<p><em>Hello</em> wonderful <em>World</em>.</p>'
+    format = Format(indent=True)
+    s = serialize(xml, format)
+    assert xml in s
+    xml = ("""<body py:strip="" xmlns:py="http://purl.org/kid/ns#">
+        <ul><li py:for="s in ('Hello', 'World')" py:content="s" /></ul></body>""")
+    format = Format(indent=True, min_level=0, no_empty_lines=True)
+    s = serialize(xml, format)
+    assert '<ul>\n\t<li>Hello</li>\n\t<li>World</li>\n</ul>' in s
 
 def test_format_wrap():
     xml = """<body>
