@@ -1,7 +1,9 @@
+# -*- coding: utf-8 -*-
+
 """kid.serialization tests."""
 
-__revision__ = "$Rev: 429 $"
-__date__ = "$Date: 2006-10-26 09:24:33 -0400 (Thu, 26 Oct 2006) $"
+__revision__ = "$Rev: 492 $"
+__date__ = "$Date: 2007-07-06 21:38:45 -0400 (Fri, 06 Jul 2007) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -46,7 +48,8 @@ def test_xhtml_output_method():
     for output in 'xhtml', 'xhtml-strict':
         rslt = t.serialize(output=output)
         expected = serialize_doctype(doctypes[output]) \
-                   + '\n<html xmlns="http://www.w3.org/1999/xhtml"><p>test</p>' \
+                   + '\n<html xmlns="http://www.w3.org/1999/xhtml">' \
+                   + '<p>test</p>' \
                    + '<img src="some.gif" /><br /></html>'
         assert rslt == expected
 
@@ -74,7 +77,7 @@ def test_xml_output_method():
 from kid.serialization import HTMLSerializer, XMLSerializer, XHTMLSerializer
 serializer = HTMLSerializer()
 serializer.doctype = None
-serializer.inject_type = 0
+serializer.inject_type = False
 
 def HTMLTemplate(text, **kw):
     t = kid.Template(text, **kw)
@@ -150,20 +153,23 @@ def test_html_boolean_attributes():
 def test_doctype_and_injection():
     serializer = HTMLSerializer(encoding='utf-8', transpose=True)
     serializer.doctype = doctypes['html-strict']
-    serializer.inject_type = 1
+    serializer.inject_type = True
     source = "<html><head /></html>"
     t = kid.Template(source)
     t.serializer = serializer
-    rslt = t.serialize()
+    from kid.format import Format
+    format=Format(no_empty_lines=True)
+    rslt = t.serialize(format=format)
+    rslt = rslt.replace('\n', '')
     expected = ('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"'
-        ' "http://www.w3.org/TR/html4/strict.dtd">\n'
+        ' "http://www.w3.org/TR/html4/strict.dtd">'
         '<HTML><HEAD>'
         '<META CONTENT="text/html; charset=utf-8" HTTP-EQUIV="content-type">'
         '</HEAD></HTML>')
     assert rslt == expected
     serializer = HTMLSerializer(encoding='ascii', transpose=False)
     serializer.doctype = None
-    serializer.inject_type = 1
+    serializer.inject_type = True
     source = ('<html><head>'
         '<meta content="Reiner Wahnsinn" name="author"/>'
         '<meta content="nonsense" http-equiv="content-type"/>'
@@ -179,6 +185,7 @@ def test_doctype_and_injection():
     t = kid.Template(source)
     t.serializer = serializer
     rslt = t.serialize()
+    rslt = rslt.replace('\n', '')
     expected = source.replace('/>', '>').replace('<title>',
         '<meta content="text/html; charset=ascii"'
         ' http-equiv="content-type"><title>')
@@ -242,7 +249,7 @@ def test_output_methods():
                 r = r.replace('HELLO', 'Hello').replace('WORLD', 'World')
             r = '\n' + r
             assert s.endswith(r)
-        elif output == 'xml':
+        elif output.endswith('ml'): # xml or wml
             assert s.startswith('<?xml version="1.0" encoding="utf-8"?>\n')
             assert s.endswith(xml)
         else:
@@ -254,8 +261,9 @@ def test_strip_lang():
     serializer.doctype = doctypes['html-strict']
     t = kid.Template("<html xml:lang='en' lang='en' />")
     t.serializer = serializer
-    expected = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">\n'\
-               '<HTML LANG="en"></HTML>'
+    expected = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"' \
+        ' "http://www.w3.org/TR/html4/strict.dtd">\n' \
+        '<HTML LANG="en"></HTML>'
     rslt = t.serialize()
     assert rslt == expected
 
@@ -263,7 +271,7 @@ import string
 def test_transpose_lower():
     serializer = HTMLSerializer()
     serializer.doctype = None
-    serializer.inject_type = 0
+    serializer.inject_type = False
     serializer.transpose = string.lower
     t = kid.Template("<HTML><HEAD /></HTML>")
     t.serializer = serializer
@@ -274,7 +282,7 @@ def test_transpose_lower():
 def test_transpose_off():
     serializer = HTMLSerializer()
     serializer.doctype = None
-    serializer.inject_type = 0
+    serializer.inject_type = False
     serializer.transpose = None
     t = kid.Template("<HTML><HEAD /></HTML>")
     t.serializer = serializer
