@@ -1,6 +1,6 @@
 """Unicode tests"""
 
-from kid.pull import to_unicode
+from kid.parser import to_unicode
 
 astr = '\xe2\x80\xa0\xc2\xa9\xe2\x80\x94'
 ustr = astr.decode('utf-8')
