@@ -18,10 +18,13 @@ when assertions fail. You can also run this test suite directly by:
 You can omit the -x option in all of the above commands if you do
 not want the testing to stop after the first failed test.
 
+(In order to run the tests, you need to install ElementTree
+in Python versions < 2.5.)
+
 """
 
 import sys
-from os.path import dirname, abspath, join as joinpath
+from os.path import dirname, abspath, join as joinpath, exists
 
 if __name__ == '__main__':
     __file__ = sys.argv[0]
@@ -29,6 +32,10 @@ base_dir = abspath(dirname(__file__))
 if not base_dir in sys.path:
     sys.path.insert(1, base_dir)
 test_dir = joinpath(base_dir, 'test')
+assert exists(test_dir), "Test template directory missing."
+assert not exists(joinpath(base_dir, 'build')) \
+    and not exists(joinpath(base_dir, 'dist')), \
+    "Please remove build and dist directories before testing."
 
 import kid.test
 kid.test.template_package = 'test.'
